package com.hw.mes.controller;

import java.util.List;
import java.io.IOException;
import javax.servlet.http.HttpServletResponse;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.hw.common.log.annotation.Log;
import com.hw.common.log.enums.BusinessType;
import com.hw.common.security.annotation.RequiresPermissions;
import com.hw.mes.domain.MesBaseAttachInfo;
import com.hw.mes.service.IMesBaseAttachInfoService;
import com.hw.common.core.web.controller.BaseController;
import com.hw.common.core.web.domain.AjaxResult;
import com.hw.common.core.utils.poi.ExcelUtil;
import com.hw.common.core.web.page.TableDataInfo;

/**
 * 附件信息Controller
 * 
 * @author Yinq
 * @date 2024-01-26
 */
@RestController
@RequestMapping("/baseAttachInfo")
public class MesBaseAttachInfoController extends BaseController
{
    @Autowired
    private IMesBaseAttachInfoService mesBaseAttachInfoService;

    /**
     * 查询附件信息列表
     */
    @RequiresPermissions("mes:baseAttachInfo:list")
    @GetMapping("/list")
    public TableDataInfo list(MesBaseAttachInfo mesBaseAttachInfo)
    {
        startPage();
        List<MesBaseAttachInfo> list = mesBaseAttachInfoService.selectMesBaseAttachInfoList(mesBaseAttachInfo);
        return getDataTable(list);
    }

    /**
     * 导出附件信息列表
     */
    @RequiresPermissions("mes:baseAttachInfo:export")
    @Log(title = "附件信息", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    public void export(HttpServletResponse response, MesBaseAttachInfo mesBaseAttachInfo)
    {
        List<MesBaseAttachInfo> list = mesBaseAttachInfoService.selectMesBaseAttachInfoList(mesBaseAttachInfo);
        ExcelUtil<MesBaseAttachInfo> util = new ExcelUtil<MesBaseAttachInfo>(MesBaseAttachInfo.class);
        util.exportExcel(response, list, "附件信息数据");
    }

    /**
     * 获取附件信息详细信息
     */
    @RequiresPermissions("mes:baseAttachInfo:query")
    @GetMapping(value = "/{attachId}")
    public AjaxResult getInfo(@PathVariable("attachId") Long attachId)
    {
        return success(mesBaseAttachInfoService.selectMesBaseAttachInfoByAttachId(attachId));
    }

    /**
     * 新增附件信息
     */
    @RequiresPermissions("mes:baseAttachInfo:add")
    @Log(title = "附件信息", businessType = BusinessType.INSERT)
    @PostMapping
    public AjaxResult add(@RequestBody MesBaseAttachInfo mesBaseAttachInfo)
    {
        return toAjax(mesBaseAttachInfoService.insertMesBaseAttachInfo(mesBaseAttachInfo));
    }

    /**
     * 修改附件信息
     */
    @RequiresPermissions("mes:baseAttachInfo:edit")
    @Log(title = "附件信息", businessType = BusinessType.UPDATE)
    @PutMapping
    public AjaxResult edit(@RequestBody MesBaseAttachInfo mesBaseAttachInfo)
    {
        return toAjax(mesBaseAttachInfoService.updateMesBaseAttachInfo(mesBaseAttachInfo));
    }

    /**
     * 删除附件信息
     */
    @RequiresPermissions("mes:baseAttachInfo:remove")
    @Log(title = "附件信息", businessType = BusinessType.DELETE)
	@DeleteMapping("/{attachIds}")
    public AjaxResult remove(@PathVariable Long[] attachIds)
    {
        return toAjax(mesBaseAttachInfoService.deleteMesBaseAttachInfoByAttachIds(attachIds));
    }
}
