package com.hw.mes.service.impl;

import java.util.List;
import com.hw.common.core.utils.DateUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import com.hw.mes.mapper.MesMaterialBomMapper;
import com.hw.mes.domain.MesMaterialBom;
import com.hw.mes.service.IMesMaterialBomService;

/**
 * 物料BOM信息Service业务层处理
 *
 * @author Yinq
 * @date 2024-01-30
 */
@Service
public class MesMaterialBomServiceImpl implements IMesMaterialBomService
{
    @Autowired
    private MesMaterialBomMapper mesMaterialBomMapper;

    /**
     * 查询物料BOM信息
     *
     * @param materialBomId 物料BOM信息主键
     * @return 物料BOM信息
     */
    @Override
    public MesMaterialBom selectMesMaterialBomByMaterialBomId(Long materialBomId)
    {
        return mesMaterialBomMapper.selectMesMaterialBomByMaterialBomId(materialBomId);
    }

    /**
     * 查询物料BOM信息列表
     *
     * @param mesMaterialBom 物料BOM信息
     * @return 物料BOM信息
     */
    @Override
    public List<MesMaterialBom> selectMesMaterialBomList(MesMaterialBom mesMaterialBom)
    {
        return mesMaterialBomMapper.selectMesMaterialBomList(mesMaterialBom);
    }

    /**
     * 新增物料BOM信息
     *
     * @param mesMaterialBom 物料BOM信息
     * @return 结果
     */
    @Override
    public int insertMesMaterialBom(MesMaterialBom mesMaterialBom)
    {
        mesMaterialBom.setCreateTime(DateUtils.getNowDate());
        return mesMaterialBomMapper.insertMesMaterialBom(mesMaterialBom);
    }

    /**
     * 修改物料BOM信息
     *
     * @param mesMaterialBom 物料BOM信息
     * @return 结果
     */
    @Override
    public int updateMesMaterialBom(MesMaterialBom mesMaterialBom)
    {
        mesMaterialBom.setUpdateTime(DateUtils.getNowDate());
        return mesMaterialBomMapper.updateMesMaterialBom(mesMaterialBom);
    }

    /**
     * 批量删除物料BOM信息
     *
     * @param materialBomIds 需要删除的物料BOM信息主键
     * @return 结果
     */
    @Override
    public int deleteMesMaterialBomByMaterialBomIds(Long[] materialBomIds)
    {
        return mesMaterialBomMapper.deleteMesMaterialBomByMaterialBomIds(materialBomIds);
    }

    /**
     * 删除物料BOM信息信息
     *
     * @param materialBomId 物料BOM信息主键
     * @return 结果
     */
    @Override
    public int deleteMesMaterialBomByMaterialBomId(Long materialBomId)
    {
        return mesMaterialBomMapper.deleteMesMaterialBomByMaterialBomId(materialBomId);
    }




    /**
     * 查询物料BOM信息列表,Join material
     *
     * @param mesMaterialBom 物料BOM信息
     * @return 物料BOM信息
     */
    @Override
    public List<MesMaterialBom> selectMesMaterialBomJoinList(MesMaterialBom mesMaterialBom)
    {
        return mesMaterialBomMapper.selectMesMaterialBomJoinList(mesMaterialBom);
    }

}
